@@ -22,12 +22,10 @@ from bitmaptools import draw_line, fill_region
 from ulab import numpy as np
 from vectorio import Polygon
 
-__version__ = "0.14.1"
+__version__ = "0.15.0"
 __repo__ = "https://github.com/adafruit/CircuitPython_uplot.git"
 
 
-# pylint: disable=too-many-arguments, invalid-name, no-self-use, too-few-public-methods
-# pylint: disable=too-many-locals, too-many-branches
 class ucartesian:
     """
     Class to draw cartesian plane
@@ -123,6 +121,8 @@ class ucartesian:
             for index, _ in enumerate(xnorm):
                 if index + 1 >= len(xnorm):
                     break
+                if y[index] >= ymax:
+                    continue
                 draw_line(
                     plot._plotbitmap,
                     xnorm[index],
