@@ -23,12 +23,10 @@ from ulab import numpy as np
 import displayio
 from vectorio import Rectangle
 
-__version__ = "0.14.2"
+__version__ = "0.15.0"
 __repo__ = "https://github.com/adafruit/CircuitPython_uplot.git"
 
 
-# pylint: disable=too-few-public-methods, invalid-name, duplicate-code, too-many-locals, too-many-arguments
-# pylint: disable=unused-variable
 class umap:
     """
     Main class to display different graphics
@@ -75,8 +73,8 @@ class umap:
         deltax = plot._newxmin
         deltay = plot._newymax
         color = 0
-        for j in range(box_iny):
-            for i in range(box_inx):
+        for _ in range(box_iny):
+            for _ in range(box_inx):
                 plot.append(
                     Rectangle(
                         pixel_shader=palette,
